﻿using Leap.Unity;
using LeapInternal;
using MVR.FileManagementSecure;
using System;
using System.Collections.Generic;
using System.Linq;
using UnityEngine;
using UnityEngine.Experimental.UIElements;
using UnityEngine.UI;

namespace Ruvik
{
    class PHMove
    {
        static GameObject PHMoveUI;
        public static void InitUI()
        {
            PHMoveUI = GameObject.Find("PH_movement_menu");
            GameObject.Find("PH_movement_position").AddComponent<PHMovePosition>();
            GameObject.Find("PH_movement_rotation").AddComponent<PHMoveRotation>();
            PHMoveUI.SetActive(false);
        }
        public static void ToggleUI()
        {
            PHMoveUI.SetActive(!PHMoveUI.activeInHierarchy);
        }
    }
    class PHMovePosition : MonoBehaviour
    {
        InputField x, y, z;
        void Awake()
        {
            foreach (var tf in GetComponentsInChildren<InputField>())
            {
                switch (tf.name)
                {
                    case "PH_x":
                        x = tf;
                        break;
                    case "PH_y":
                        y = tf;
                        break;
                    case "PH_z":
                        z = tf;
                        break;
                }
            }
            GetComponentInChildren<UnityEngine.UI.Button>().onClick.AddListener(() =>
            {
                PHUndo.StoreState();
                foreach (var node in PHUtils.activeNodes)
                {
                    Vector3 defaultPos =
                        PHUtils.activeAtom.mainController.transform.position +
                        (PHUtils.activeAtom.mainController.transform.right * node.controller.startingLocalPosition.x) +
                        (PHUtils.activeAtom.mainController.transform.up * node.controller.startingLocalPosition.y) +
                        (PHUtils.activeAtom.mainController.transform.forward * node.controller.startingLocalPosition.z);
                    node.controller.MoveControl(defaultPos);
                }
            });
            x.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.MoveControl(new Vector3(i, node.controller.transform.position.y, node.controller.transform.position.z));
                }
            });
            y.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.MoveControl(new Vector3(node.controller.transform.position.x, i, node.controller.transform.position.z));
                }
            });
            z.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.MoveControl(new Vector3(node.controller.transform.position.x, node.controller.transform.position.y, i));
                }
            });
        }
        void Update()
        {
            switch (PHUtils.activeNodes.Count)
            {
                case 0:
                    x.text = "";
                    y.text = "";
                    z.text = "";
                    break;
                case 1:
                    var Controller = PHUtils.activeNodes.First().controller;
                    if (!x.isFocused)
                        x.text = $"{Math.Round(Controller.transform.position.x, 2)}";
                    if (!y.isFocused)
                        y.text = $"{Math.Round(Controller.transform.position.y, 2)}";
                    if (!z.isFocused)
                        z.text = $"{Math.Round(Controller.transform.position.z, 2)}";
                    break;
                default:
                    if (!x.isFocused)
                        x.text = "...";
                    if (!y.isFocused)
                        y.text = "...";
                    if (!z.isFocused)
                        z.text = "...";
                    break;

            }
        }
    }
    class PHMoveRotation : MonoBehaviour
    {
        InputField x, y, z;
        void Awake()
        {
            foreach (var tf in GetComponentsInChildren<InputField>())
            {
                switch (tf.name)
                {
                    case "PH_x":
                        x = tf;
                        break;
                    case "PH_y":
                        y = tf;
                        break;
                    case "PH_z":
                        z = tf;
                        break;
                }
            }
            GetComponentInChildren<UnityEngine.UI.Button>().onClick.AddListener(() =>
            {
                PHUndo.StoreState();
                foreach (var node in PHUtils.activeNodes)
                {
                    Vector3 defaultRot = PHUtils.activeAtom.mainController.transform.eulerAngles + node.controller.startingLocalRotation.eulerAngles;
                    node.controller.RotateControl(defaultRot);
                }
            });
            x.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.RotateControl(new Vector3(i, node.controller.transform.eulerAngles.y, node.controller.transform.eulerAngles.z));
                }
            });
            y.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.RotateControl(new Vector3(node.controller.transform.eulerAngles.x, i, node.controller.transform.eulerAngles.z));
                }
            });
            z.onEndEdit.AddListener((str) =>
            {
                PHUndo.StoreState();
                float i = (float)Convert.ToDouble(str.Replace(',', '.'));
                foreach (var node in PHUtils.activeNodes)
                {
                    node.controller.RotateControl(new Vector3(node.controller.transform.eulerAngles.x, node.controller.transform.eulerAngles.y, i));
                }
            });
        }
        void Update()
        {
            switch (PHUtils.activeNodes.Count)
            {
                case 0:
                    x.text = "";
                    y.text = "";
                    z.text = "";
                    break;
                case 1:
                    var Controller = PHUtils.activeNodes.First().controller;
                    if (!x.isFocused)
                        x.text = $"{Math.Round(Controller.transform.eulerAngles.x, 2)}";
                    if (!y.isFocused)
                        y.text = $"{Math.Round(Controller.transform.eulerAngles.y, 2)}";
                    if (!z.isFocused)
                        z.text = $"{Math.Round(Controller.transform.eulerAngles.z, 2)}";
                    break;
                default:
                    if (!x.isFocused)
                        x.text = "...";
                    if (!y.isFocused)
                        y.text = "...";
                    if (!z.isFocused)
                        z.text = "...";
                    break;

            }
        }
    }
}
